@@ -71,11 +71,15 @@ class InputFile(object):
         else:
             old_data = ""
 
-        assert self._buf_position == self._file_position
+        assert self._buf_position == self._file_position, (
+            "Before reading buffer position (%i) didn't match file position (%i)" %
+            (self._buf_position, self._file_position))
         new_data = self._file.read(bytes_remaining)
         self._buf.write(new_data)
         self._file_position += bytes_remaining
-        assert self._buf_position == self._file_position
+        assert self._buf_position == self._file_position, (
+            "After reading buffer position (%i) didn't match file position (%i)" %
+            (self._buf_position, self._file_position))
 
         return old_data + new_data
 
